﻿/// @file config.cpp
///
/// @brief config
///
#include "config.h"
#include <wx/filename.h>
#include <wx/fileconf.h>

Config gConfig;

Config::Config()
{
	ini_file = _T("");

	// default value
	mFilePath = _T("");
	mMemoryCash = false;
	mServerHost = _T("localhost");
	mServerPort = _T("10200");
	mPrintDelay = 16;
}

Config::~Config()
{
}

void Config::SetFileName(const wxString &file)
{
	ini_file = file;
}

void Config::Load()
{
	if (ini_file.IsEmpty()) return;

	// load ini file
	wxFileConfig *ini = new wxFileConfig(wxEmptyString,wxEmptyString,ini_file,wxEmptyString
		,wxCONFIG_USE_LOCAL_FILE | wxCONFIG_USE_RELATIVE_PATH | wxCONFIG_USE_NO_ESCAPE_CHARACTERS);

	int i;
	long l;
	wxString s;
	ini->Read(_T("Path"), &mFilePath, mFilePath);
	ini->Read(_T("MemoryCash"), &mMemoryCash, mMemoryCash);
	ini->Read(_T("ServerHost"), &mServerHost, mServerHost);
	ini->Read(_T("ServerPort"), &s, mServerPort);
	s.ToLong(&l);
	if (0 < l && l <= 65535) mServerPort = s;
	ini->Read(_T("PrintDelay"), &i, mPrintDelay);
	if (0 <= i && i <= 10000) mPrintDelay = i; 
	delete ini;
}

void Config::Load(const wxString &file)
{
	SetFileName(file);
	Load();
}

void Config::Save()
{
	if (ini_file.IsEmpty()) return;

	// save ini file
	wxFileConfig *ini = new wxFileConfig(wxEmptyString,wxEmptyString,ini_file,wxEmptyString
		,wxCONFIG_USE_LOCAL_FILE | wxCONFIG_USE_RELATIVE_PATH | wxCONFIG_USE_NO_ESCAPE_CHARACTERS);
	ini->Write(_T("Path"), mFilePath);
	ini->Write(_T("MemoryCash"), mMemoryCash);
	ini->Write(_T("ServerHost"), mServerHost);
	ini->Write(_T("ServerPort"), mServerPort);
	ini->Write(_T("PrintDelay"), mPrintDelay);
	// write
	delete ini;
}
